@@ -290,29 +290,36 @@ def resample_summary_to_daily(para_combination, folder=''):
     save_path = generate_filepath(para_combination=para_combination,folder=folder,file_format=file_format)
     if file_format == 'parquet':
         df_backtest = pd.read_parquet(save_path) # Daraframe that may not be daily
+        ### parquet specific, All backtest force to treart as summary, # ie filter action only
+        df_backtest = df_backtest.loc[df_backtest['action'] != ''].copy()
     else:
         df_backtest = pd.read_csv(save_path, index_col=0)  # Daraframe that may not be daily
+        ### csv only specific, All backtest force to treart as summary, ie filter action only
+        df_backtest = df_backtest.loc[df_backtest['action'].isnull() == False].copy()
 
     df_backtest['date'] = pd.to_datetime(df_backtest['date'], format='%Y-%m-%d')
     df_backtest = df_backtest.loc[(df_backtest['date'] >= start_date) & (df_backtest['date'] <= end_date)]
-    df_backtest = df_backtest.loc[df_backtest['action'].isnull() == False].copy() # All backtest force to treart as summary, ie filter action only
     df_backtest = df_backtest.reset_index(drop=True)  # Reset Index
 
+
     trade_pair = zip(*(iter(list(df_backtest.index)),) * 2)  # Group df_backtest by 2
     initial_capital = df_backtest.iloc[-1].equity_value - df_backtest['realized_pnl'].sum()
     last_realized_capital = initial_capital
 
+
     # Read source data
     data_folder = para_combination['data_folder']
     code = para_combination['code']
 
 
     data_path = os.path.join(folder,data_folder, f'{code}_{freq}.{file_format}')
+
     if file_format == 'parquet':
         df_csv = pd.read_parquet(data_path)
     else:
         df_csv = pd.read_csv(data_path, index_col=0)
 
+
     df_csv = df_csv.reset_index(drop=False)
 
 
@@ -339,6 +346,9 @@ def resample_summary_to_daily(para_combination, folder=''):
     df_daily['unrealized_pnl'] = None
     df_daily['signal_value'] = None
 
+
+
+
     for i, j in trade_pair:
         open_date = df_backtest.at[i, 'date']
         close_date = df_backtest.at[j, 'date']
@@ -422,6 +432,7 @@ def resample_summary_to_daily(para_combination, folder=''):
         # print()
 
     last_equity_value = initial_capital
+
     for i in df_daily.index[1:]:
         if df_daily.at[i, 'realized_pnl']:
             df_daily.at[i, 'equity_value'] = last_equity_value + df_daily.at[i, 'realized_pnl']
@@ -432,7 +443,6 @@ def resample_summary_to_daily(para_combination, folder=''):
 
     df_daily['equity_value'] = df_daily['equity_value'].fillna(method='ffill')  # Fill na for equity value only
 
-    # df_daily.to_csv('df_daily.csv')
 
     return df_daily
 
@@ -553,8 +563,14 @@ def cal_performance(para_combination):
             result_dict[str(year)] = 0
             result_dict[f'{year}_win_rate'] = '--'
 
+
+    # Performance by year
+
+
     result_dict['return_to_bah'] = return_on_capital - bah_return
     result_dict['risk_free_rate'] = risk_free_rate
 
+
+
     return result_dict
 
