@@ -10,16 +10,19 @@ class Aggregate:
     df_equity_curves = pd.DataFrame()
     df_ready = False
 
-    def __new__(self):
+    init = True
+
+    def __new__(self, risk_free_rate):
 
         chart_bg = self.chart_bg
-        components = Components()
+        components = Components(0)
         valid_colour = self.valid_colour
 
         empty_line_chart = components.empty_line_chart()
 
         self.df_equity_curves, checklist_div = components.aggregate_df()
 
+
         app = Dash(__name__, external_stylesheets=[dbc.themes.SUPERHERO], suppress_callback_exceptions=True)
 
         my_css_data = """body {
@@ -175,6 +178,23 @@ class Aggregate:
         )
         def aggregate_chart(curve_checklist,normalized_boolean, aggregate_boolean):
 
+            if self.init:
+                self.init = False
+                fig_line = px.line()
+                fig_line.update_layout(title={'text': ''})
+                fig_line.update_xaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
+                fig_line.update_yaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
+                fig_line.update_layout(plot_bgcolor='#1a2245', paper_bgcolor='#1a2245', height=650,
+                                       margin=dict(l=0, r=25, t=60, b=0),
+                                       showlegend=True,
+                                       font={"color": "white", 'size': 10.5}, yaxis={'title': ''},
+                                       xaxis={'title': ''}
+                                       )
+                normalized_style = {}
+                aggregate_style = {}
+                aggregate_performance = html.Div()
+                return fig_line, normalized_style, aggregate_style, aggregate_performance
+
             while not self.df_ready:
                 time.sleep(0.2)
 
@@ -207,9 +227,19 @@ class Aggregate:
             # Aggregate Equity
             dfs = []
             for i, path in enumerate(paths):
+                file_format = para_combination[i]['file_format']
                 intraday = para_combination[i]['intraday']
                 summary = para_combination[i]['summary_mode']
-                df_csv = pd.read_csv(path, index_col='date')
+
+                # df_csv = pd.read_csv(path, index_col='date')
+                if file_format == 'parquet':
+                    df_csv = pd.read_parquet(path)  # Daraframe that may not be daily
+                else:
+                    df_csv = pd.read_csv(path, index_col=0)
+
+                df_csv['date'] = pd.to_datetime(df_csv['date'], format='%Y-%m-%d')
+                df_csv = df_csv.set_index('date')
+
                 if (intraday or summary):
                     df = plotguy.resample_summary_to_daily(para_combination=para_combination[i],folder=folders[i])
                 else:
@@ -286,7 +316,9 @@ class Aggregate:
             return_on_capital = total_dict['return_on_capital']
 
             annualized_return = (1 + return_on_capital) ** (365 / holding_period_day) - 1
+
             annualized_std = equity_value_pct_series.std() * math.sqrt(365)
+
             if annualized_std > 0:
                 annualized_sr = annualized_return / annualized_std
             else:
@@ -300,7 +332,7 @@ class Aggregate:
             end_date_year = df_all_curves.loc[df_all_curves.index[-1], 'date'].year
             year_list = list(range(start_date_year, end_date_year + 1))
 
-            aggregate_performance = components.aggregate_performance(total_dict, year_list)
+            aggregate_performance = components.aggregate_performance(total_dict, year_list, risk_free_rate)
 
 
             # Generate Chart
