@@ -104,10 +104,23 @@ class Components:
                 pass
             checkbox_values[key] = unique_values
 
+
+
         checkbox_div = []
         for i, para_name in enumerate (para_dict):
-            # if not para_name == 'code':
-            _options = checkbox_values[para_name]
+
+            _options = []
+
+            if para_name == 'code':
+                for option in checkbox_values[para_name]:
+                    if isinstance(option, int):
+                        _options.append(str(option).zfill(5))
+                    else:
+                        _options.append(option)
+            else:
+                _options = checkbox_values[para_name]
+
+
             if _options == [False, True]:
                 _checklist = dcc.Checklist([str(tf) for tf in _options], [str(tf) for tf in _options], inline=True,
                                            id={'type': 'para-checklist', 'index': i},
@@ -445,7 +458,7 @@ class Components:
 
         data_folder = para_combination['data_folder']
         code = para_combination['code']
-        data_path = os.path.join(data_folder, code + '.csv')
+        data_path = os.path.join(data_folder, f'{code}_{freq}.{file_format}')
         # df = pd.read_csv(data_path)
         if file_format == 'parquet':
             df = pd.read_parquet(data_path)  # Daraframe that may not be daily
@@ -453,6 +466,9 @@ class Components:
             df = pd.read_csv(data_path, index_col=0)
 
 
+        df = df.reset_index(drop=False)
+
+
         df['date'] = pd.to_datetime(df['date'], format='%Y-%m-%d')
         df['datetime'] = pd.to_datetime(df['datetime'], format='%Y-%m-%d %H:%M:%S')
         df = df.loc[(df['date'] >= chart3_start) & (df['date'] <= chart3_end)]
@@ -591,6 +607,7 @@ class Components:
 
                 df_daily = df_backtest.copy()
 
+
             start_date = para_combination['start_date']
             end_date = para_combination['end_date']
             df_daily['date'] = pd.to_datetime(df_daily['date'], format='%Y-%m-%d')
