@@ -516,6 +516,13 @@ class Plot:
 
                         for element in para_checklist[i]: # -1 because code / para_dict index
 
+                            # Change back hk stock code to int
+                            if key == 'code':
+                                try:
+                                    element = int(element)
+                                except:
+                                    pass
+
                             if element == 'True':element = True
                             elif element == 'False':element = False
                             # if key == 'tolerance':
